@@ -37,20 +37,18 @@ var loadSchema = function (models, callback) {
         callback(err);
     });
 }
-module.exports = function (callback, app) {
+module.exports = function (app) {
     fscan.scan(work_dir + "/app/models", ".model.json", true, function (err, models) {
         loadSchema(models, function (err) {
             logger.info("Load Data Mode is ok");
-
-
-            app.use(function (req, res, next) {
-                req.ajv = ajv;
-                next();
-            });
-
-            callback();
         });
     });
 
 
+    app.use(function (req, res, next) {
+        req.ajv = ajv;
+        next();
+    });
+
+
 }
\ No newline at end of file
